==> rong-ui-react-0.0.7.tgz: package/es/picker/picker.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React from "react";
import { memo, forwardRef, useContext, useState, useEffect, useMemo, useImperativeHandle, useRef, useCallback } from 'react';
import { createPortal } from 'react-dom';
import { createNamespace, classNames, setDefaultProps } from '../_util';
import PropTypes from 'prop-types';
import PickerColumn from './picker-column';

var _createNamespace = createNamespace('picker'),
    bem = _createNamespace.bem;

var PickerPortal = /*#__PURE__*/function (_React$Component) {
  _inherits(PickerPortal, _React$Component);

  var _super = _createSuper(PickerPortal);

  function PickerPortal(props) {
    var _this;

    _classCallCheck(this, PickerPortal);

    _this = _super.call(this, props);
    _this.el = document.createElement('div');
    _this.el.className = 'picker-portal';

    _this.__handlePreventDefault__ = function (e) {
      return e.preventDefault();
    };

    _this.pickerRef = React.createRef();
    return _this;
  }

  _createClass(PickerPortal, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.el.addEventListener('touchmove', this.__handlePreventDefault__);
      document.body.appendChild(this.el);
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.el.removeEventListener('touchmove', this.__handlePreventDefault__);
      document.body.removeChild(this.el);
    }
  }, {
    key: "show",
    value: function show() {
      this.pickerRef.current.show();
    }
  }, {
    key: "hide",
    value: function hide() {
      this.pickerRef.current.hide();
    }
  }, {
    key: "resetField",
    value: function resetField() {
      this.pickerRef.current.resetField();
    }
  }, {
    key: "render",
    value: function render() {
      return /*#__PURE__*/createPortal( /*#__PURE__*/React.createElement(Picker, _extends({}, this.props, {
        ref: this.pickerRef
      })), this.el);
    }
  }]);

  return PickerPortal;
}(React.Component);

var Picker = /*#__PURE__*/forwardRef(function (props, ref) {
  var cancelBtnText = props.cancelBtnText,
      confirmBtnText = props.confirmBtnText,
      columns = props.columns,
      columnsValue = props.columnsValue,
      visibleItemCount = props.visibleItemCount,
      onCancel = props.onCancel,
      onConfirm = props.onConfirm,
      onChange = props.onChange;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      _showPicker = _useState2[0],
      setShowPicker = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      _showMask = _useState4[0],
      setShowMask = _useState4[1];

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      _showPanel = _useState6[0],
      setShowPanel = _useState6[1];

  var _useState7 = useState(0),
      _useState8 = _slicedToArray(_useState7, 2),
      _itemHeight = _useState8[0],
      setItemHeight = _useState8[1];

  var _useState9 = useState([].concat(columns)),
      _useState10 = _slicedToArray(_useState9, 2),
      _columns = _useState10[0],
      setColumnsData = _useState10[1];

  var _useState11 = useState([].concat(columnsValue)),
      _useState12 = _slicedToArray(_useState11, 2),
      _columnsValue = _useState12[0],
      setColumnsDataValue = _useState12[1];

  var _useState13 = useState(new Date().getTime()),
      _useState14 = _slicedToArray(_useState13, 2),
      _timeStamp = _useState14[0],
      setTimeStamp = _useState14[1];

  var baseOffset = _itemHeight * (visibleItemCount - 1) / 2;
  var pickerEl = null;
  var columnsEl = null; // 异步更新

  useEffect(function () {
    return setColumnsData([].concat(columns));
  }, [columns]); // useEffect(() => {
  //   document.body.appendChild(pickerEl)
  //   return () => document.body.removeChild(pickerEl)
  // }, [])
  // 获取li高度

  useEffect(function () {
    if (!_itemHeight) {
      var li = columnsEl.querySelector('li');
      if (li) setItemHeight(window.getComputedStyle(li).height.match(/\d*\.?\d*/)[0] * 1 || 44);
    }
  });

  var toShowPicker = function toShowPicker() {
    setShowPicker(true);
    setShowMask(true);
    setShowPanel(true);
  };

  var toHidePicker = function toHidePicker() {
    setShowPicker(false);
    setShowMask(false);
    setShowPanel(false);
  };

  useImperativeHandle(ref, function () {
    return {
      show: toShowPicker,
      hide: toHidePicker,
      resetField: function resetField() {
        setColumnsData([].concat(columns));
        setTimeStamp(new Date().getTime());
      }
    };
  });
  var handleColumnChange = useCallback(function (columnIndex, selectedIndex, column) {
    var children = column[selectedIndex].children;

    if (children) {
      _columns[columnIndex + 1] = children;
      setTimeout(function () {
        return setColumnsData([].concat(_columns));
      }, 10);
    }

    _columnsValue[columnIndex] = column[selectedIndex]; // [ {text: "浙江省", value: "330000" }, { text: "绍兴市", value: "330600"}, { text: "上虞区", value: "330604" }]

    onChange(_columnsValue);
  }, [_columns]);

  var handleCancelClick = function handleCancelClick(e) {
    onCancel(_columnsValue);
    toHidePicker();
  };

  var handleConfirmClick = function handleConfirmClick(e) {
    onConfirm(_columnsValue);
    toHidePicker();
  };

  console.log('picker mounted or update');
  return /*#__PURE__*/React.createElement("div", {
    className: bem({
      show: _showPicker
    }),
    ref: function ref(el) {
      return pickerEl = el;
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: bem('mask', {
      show: _showMask
    })
  }), /*#__PURE__*/React.createElement("div", {
    className: bem('panel', {
      show: _showPanel
    })
  }, /*#__PURE__*/React.createElement("div", {
    className: bem('toolbar')
  }, /*#__PURE__*/React.createElement("div", {
    className: bem('cancel'),
    onClick: handleCancelClick
  }, cancelBtnText ? cancelBtnText : '取消'), /*#__PURE__*/React.createElement("div", {
    className: bem('confirm'),
    onClick: handleConfirmClick
  }, confirmBtnText ? confirmBtnText : '确认')), /*#__PURE__*/React.createElement("div", {
    className: classNames([bem('columns'), 'scroll-area']),
    ref: function ref(el) {
      return columnsEl = el;
    }
  }, _columns.map(function (column, index) {
    return column.length ? /*#__PURE__*/React.createElement(PickerColumn, {
      column: column,
      columnValue: columnsValue[index] != undefined ? columnsValue[index] : '',
      columnIndex: index,
      itemHeight: _itemHeight,
      baseOffset: baseOffset,
      timeStamp: _timeStamp,
      onChange: handleColumnChange,
      key: index
    }) : '';
  }), /*#__PURE__*/React.createElement("div", {
    className: bem('columns-mask')
  }), /*#__PURE__*/React.createElement("div", {
    className: bem('columns-hairline')
  }))));
});
setDefaultProps(Picker, {
  columns: {
    type: PropTypes.array
  },
  columnsValue: {
    type: PropTypes.array
  },
  // 可见的选项个数
  visibleItemCount: {
    type: PropTypes.number,
    default: 6
  },
  // 取消按钮文字
  cancelBtnText: {
    type: PropTypes.node
  },
  // 确认按钮文字
  confirmBtnText: {
    type: PropTypes.node
  },
  // 选项改变时触发
  onChange: {
    type: PropTypes.func,
    default: function _default() {}
  },
  // 点击完成按钮时触发
  onConfirm: {
    type: PropTypes.func,
    default: function _default() {}
  },
  // 点击取消按钮时触发
  onCancel: {
    type: PropTypes.func,
    default: function _default() {}
  }
});
export default /*#__PURE__*/memo(PickerPortal);

==> rong-ui-react-0.0.8.tgz: package/es/picker/picker.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
import React from "react";
import { memo, forwardRef, useContext, useState, useEffect, useMemo, useImperativeHandle, useRef, useCallback } from 'react';
import { createPortal } from 'react-dom';
import { createNamespace, classNames, setDefaultProps } from '../_util';
import PropTypes from 'prop-types';
import PickerColumn from './picker-column';
var _createNamespace = createNamespace('picker'),
  bem = _createNamespace.bem;
var PickerPortal = /*#__PURE__*/function (_React$Component) {
  _inherits(PickerPortal, _React$Component);
  var _super = _createSuper(PickerPortal);
  function PickerPortal(props) {
    var _this;
    _classCallCheck(this, PickerPortal);
    _this = _super.call(this, props);
    _this.el = document.createElement('div');
    _this.el.className = 'picker-portal';
    _this.__handlePreventDefault__ = function (e) {
      return e.preventDefault();
    };
    _this.pickerRef = /*#__PURE__*/React.createRef();
    return _this;
  }
  _createClass(PickerPortal, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.el.addEventListener('touchmove', this.__handlePreventDefault__);
      document.body.appendChild(this.el);
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.el.removeEventListener('touchmove', this.__handlePreventDefault__);
      document.body.removeChild(this.el);
    }
  }, {
    key: "show",
    value: function show() {
      this.pickerRef.current.show();
    }
  }, {
    key: "hide",
    value: function hide() {
      this.pickerRef.current.hide();
    }
  }, {
    key: "resetField",
    value: function resetField() {
      this.pickerRef.current.resetField();
    }
  }, {
    key: "render",
    value: function render() {
      return /*#__PURE__*/createPortal( /*#__PURE__*/React.createElement(Picker, _extends({}, this.props, {
        ref: this.pickerRef
      })), this.el);
    }
  }]);
  return PickerPortal;
}(React.Component);
var Picker = /*#__PURE__*/forwardRef(function (props, ref) {
  var cancelBtnText = props.cancelBtnText,
    confirmBtnText = props.confirmBtnText,
    columns = props.columns,
    columnsValue = props.columnsValue,
    visibleItemCount = props.visibleItemCount,
    onCancel = props.onCancel,
    onConfirm = props.onConfirm,
    onChange = props.onChange;
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    _showPicker = _useState2[0],
    setShowPicker = _useState2[1];
  var _useState3 = useState(false),
    _useState4 = _slicedToArray(_useState3, 2),
    _showMask = _useState4[0],
    setShowMask = _useState4[1];
  var _useState5 = useState(false),
    _useState6 = _slicedToArray(_useState5, 2),
    _showPanel = _useState6[0],
    setShowPanel = _useState6[1];
  var _useState7 = useState(0),
    _useState8 = _slicedToArray(_useState7, 2),
    _itemHeight = _useState8[0],
    setItemHeight = _useState8[1];
  var _useState9 = useState([].concat(columns)),
    _useState10 = _slicedToArray(_useState9, 2),
    _columns = _useState10[0],
    setColumnsData = _useState10[1];
  var _useState11 = useState([].concat(columnsValue)),
    _useState12 = _slicedToArray(_useState11, 2),
    _columnsValue = _useState12[0],
    setColumnsDataValue = _useState12[1];
  var _useState13 = useState(new Date().getTime()),
    _useState14 = _slicedToArray(_useState13, 2),
    _timeStamp = _useState14[0],
    setTimeStamp = _useState14[1];
  var baseOffset = _itemHeight * (visibleItemCount - 1) / 2;
  var pickerEl = null;
  var columnsEl = null;

  // 异步更新
  useEffect(function () {
    return setColumnsData([].concat(columns));
  }, [columns]);

  // useEffect(() => {
  //   document.body.appendChild(pickerEl)
  //   return () => document.body.removeChild(pickerEl)
  // }, [])

  // 获取li高度
  useEffect(function () {
    if (!_itemHeight) {
      var li = columnsEl.querySelector('li');
      if (li) setItemHeight(window.getComputedStyle(li).height.match(/\d*\.?\d*/)[0] * 1 || 44);
    }
  });
  var toShowPicker = function toShowPicker() {
    setShowPicker(true);
    setShowMask(true);
    setShowPanel(true);
  };
  var toHidePicker = function toHidePicker() {
    setShowPicker(false);
    setShowMask(false);
    setShowPanel(false);
  };
  useImperativeHandle(ref, function () {
    return {
      show: toShowPicker,
      hide: toHidePicker,
      resetField: function resetField() {
        setColumnsData([].concat(columns));
        setTimeStamp(new Date().getTime());
      }
    };
  });
  var handleColumnChange = useCallback(function (columnIndex, selectedIndex, column) {
    var children = column[selectedIndex].children;
    if (children) {
      _columns[columnIndex + 1] = children;
      setTimeout(function () {
        return setColumnsData([].concat(_columns));
      }, 10);
    }
    _columnsValue[columnIndex] = column[selectedIndex]; // [ {text: "浙江省", value: "330000" }, { text: "绍兴市", value: "330600"}, { text: "上虞区", value: "330604" }]
    onChange(_columnsValue);
  }, [_columns]);
  var handleCancelClick = function handleCancelClick(e) {
    onCancel(_columnsValue);
    toHidePicker();
  };
  var handleConfirmClick = function handleConfirmClick(e) {
    onConfirm(_columnsValue);
    toHidePicker();
  };
  console.log('picker mounted or update');
  return /*#__PURE__*/React.createElement("div", {
    className: bem({
      show: _showPicker
    }),
    ref: function ref(el) {
      return pickerEl = el;
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: bem('mask', {
      show: _showMask
    })
  }), /*#__PURE__*/React.createElement("div", {
    className: bem('panel', {
      show: _showPanel
    })
  }, /*#__PURE__*/React.createElement("div", {
    className: bem('toolbar')
  }, /*#__PURE__*/React.createElement("div", {
    className: bem('cancel'),
    onClick: handleCancelClick
  }, cancelBtnText ? cancelBtnText : '取消'), /*#__PURE__*/React.createElement("div", {
    className: bem('confirm'),
    onClick: handleConfirmClick
  }, confirmBtnText ? confirmBtnText : '确认')), /*#__PURE__*/React.createElement("div", {
    className: classNames([bem('columns'), 'scroll-area']),
    ref: function ref(el) {
      return columnsEl = el;
    }
  }, _columns.map(function (column, index) {
    return column.length ? /*#__PURE__*/React.createElement(PickerColumn, {
      column: column,
      columnValue: columnsValue[index] != undefined ? columnsValue[index] : '',
      columnIndex: index,
      itemHeight: _itemHeight,
      baseOffset: baseOffset,
      timeStamp: _timeStamp,
      onChange: handleColumnChange,
      key: index
    }) : '';
  }), /*#__PURE__*/React.createElement("div", {
    className: bem('columns-mask')
  }), /*#__PURE__*/React.createElement("div", {
    className: bem('columns-hairline')
  }))));
});
setDefaultProps(Picker, {
  columns: {
    type: PropTypes.array
  },
  columnsValue: {
    type: PropTypes.array
  },
  // 可见的选项个数
  visibleItemCount: {
    type: PropTypes.number,
    default: 6
  },
  // 取消按钮文字
  cancelBtnText: {
    type: PropTypes.node
  },
  // 确认按钮文字
  confirmBtnText: {
    type: PropTypes.node
  },
  // 选项改变时触发
  onChange: {
    type: PropTypes.func,
    default: function _default() {}
  },
  // 点击完成按钮时触发
  onConfirm: {
    type: PropTypes.func,
    default: function _default() {}
  },
  // 点击取消按钮时触发
  onCancel: {
    type: PropTypes.func,
    default: function _default() {}
  }
});
export default /*#__PURE__*/memo(PickerPortal);
